@@ -261,6 +261,23 @@ impl From<nvmlProcessInfo_t> for ProcessInfo {
     }
 }
 
+#[cfg(feature = "legacy-functions")]
+impl From<nvmlProcessInfo_v2_t> for ProcessInfo {
+    fn from(struct_: nvmlProcessInfo_v2_t) -> Self {
+        // These versions of the struct are exactly the same, so we can rely on
+        // the above `From` impl and just treat this struct as the unversioned
+        // one.
+        let unversioned_struct = nvmlProcessInfo_t {
+            pid: struct_.pid,
+            usedGpuMemory: struct_.usedGpuMemory,
+            gpuInstanceId: struct_.gpuInstanceId,
+            computeInstanceId: struct_.computeInstanceId,
+        };
+
+        Self::from(unversioned_struct)
+    }
+}
+
 /// Detailed ECC error counts for a device.
 // Checked against local
 #[derive(Debug, Clone, Eq, PartialEq, Hash)]
@@ -570,7 +587,7 @@ impl TryFrom<nvmlFieldValue_t> for FieldValueSample {
 }
 
 /// Holds global frame buffer capture session statistics.
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, Eq, PartialEq)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct FbcStats {
     /// The total number of sessions
@@ -592,7 +609,7 @@ impl From<nvmlFBCStats_t> for FbcStats {
 }
 
 /// Information about a frame buffer capture session.
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, Eq, PartialEq)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct FbcSessionInfo {
     /// Unique session ID
